# English
This is a CSDN blogger Xin_data test project, mainly used to explain the release of custom module testing.

Note: There is nothing nutritious in the package.
# 中文
这是csdn博主Xin学数据的一个测试项目，主要是用于讲解发布自定义模块测试。
注：包中没有什么有营养的东西。